<?php
################################################################################
#  ficon.php                                                                   #
################################################################################
#    Purpose: Select 'light' / 'dark' Cumulus Forecast icon                    #
#    Authors: beteljuice  August 2012                                          #
#       info: Requires PHP 5+  if safe_mode exists ( < v5.4) should be OFF     #
#             Finds 'next' civil twilight event and together with user set     #
#             'lead' time determines 'light' or 'dark' FORECAST graphic        #
#             Lat, Lon, date, TZ, <#forecastnumber> can all be 'posted'        #
#             date and forecastnumber may be obtained from realtime.txt        #
#                                                                              #
#             requires an icon 'library' with the naming structure of          #
#             of the set available from  JacquesD                              #
#             Source: http://weatherbyyou.com/dl.php                           #
#                                                                              #
#    Version: 1.0                                                              #
################################################################################
#                                                                              #
################################################################################
# This program is free software; you can redistribute it and/or  modify it     #
# under the terms of the GNU General Public License as published by the Free   #
# Software Foundation; either version 2 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# This program is distributed in the hope that it will be useful, but          #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY   #
# or FITNESS FOR A PARTICULAR PURPOSE.                                         #
# See the GNU General Public License for more details.                         #
#                                                                              #
# You should have received a copy of the GNU General Public License along with #
# this program; if not, write to the:                                          #
#    Free Software Foundation, Inc.,                                           #
#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA                  #
################################################################################
# This document uses Tab 3 Settings                                            #
################################################################################
/*
USAGE: (html / php pages)
In a '<#webtags>' environment:
   <img src="ficon.php?fno=<#forecastnumber>&event=<#date format="yyyy'-'mm'-'dd'*'hh:nn">" .... /> prefered, using report timestamp
   <img src="ficon.php?fno=<#forecastnumber>" .... /> using 'now' timestamp
else using realtime.txt:
   <img src="ficon.php" .... /> 
*/
error_reporting(0);


//----------------------------------------------------------------------------\\
// USER SETTINGS: (required)                                                  \\
//----------------------------------------------------------------------------\\

// Next three lines added to get IsFreezing and forecastnumber data -- C. J. With 01/09/2013
include('./wt_data_inc.php');  // load data from Cumulus
$frz = "$IsFreezing";  // save IsFreezing value
$fno = "$forecastnumber"; // save forecastnumber

$time_locale = "America/Denver";  // set your timezone - see: http://php.net/manual/en/timezones.php
                                 // may be overridden by php?locale=Europe/London
// $hour = 04; // line only used for testing 
if ($hour >= 12){  // if hour is noon or later (PM)
    $lead = 1;     // the number of HOURS for the advance/subtract of the forecast graphic 
}else{             // if hour is before noon (AM)
    $lead = -1;    // the number of HOURS for the advance/subtract of the forecast graphic
}

// icon images: light format $icons$imagePrefix1_[-1 > 26]$imageType
// icon images: dark format $icons$imagePrefix0_[-1 > 26]$imageType
// preset to JacquesD naming / image type 
$icons = "style/forecast/";            // path to forecast icons directory (include trailing /)
$imageType = "png";              // [jpg] [png] [gif] - the format of your icon set
$imagePrefix = "forecast_";      // optional start of icon name(s)


$SITE['latitude']       = 35.2823; // N+, S-
$SITE['longitude']      = -106.7202; // W-, E+
// may be overridden by php?lat=103.652&lon=-74.123

$realtime = "realtime.txt";      // if using realtime.txt for timestamp and forecastno this should be
                                 // the path to the file eg. "realtime.txt"

$timeToDie = 7;                  // 'age' in HOURS after forecast before N/A is returned 
 
// date / time is default 'now' for locale set - 
// override 'now' by php?event=[unix timestamp] OR
// override 'now' by php?event=[ISO timestamp] OR
// override 'now' by using realtime.txt 
 
//--END USER SETTING ----------------------------------------------------------\\


//-- facility to view code source --
if (isset($_REQUEST['sce']) && ( strtolower($_REQUEST['sce']) == 'view' or
    strtolower($_REQUEST['sce']) == 'show') ) {
   $filenameReal = __FILE__;
   $download_size = filesize($filenameReal);
   header('Pragma: public');
   header('Cache-Control: private');
   header('Cache-Control: no-cache, must-revalidate');
   header("Content-type: text/plain");
   header("Accept-Ranges: bytes");
   header("Content-Length: $download_size");
   header('Connection: close');

   readfile($filenameReal);
   exit;
}

// check for posted values (override any defaults)
// lat / long
if(isset($_REQUEST['lat'])){
   $lat = $_REQUEST['lat'];
} else {
   $lat = $SITE['latitude'];
}

if(isset($_REQUEST['lon'])){
   $lng = $_REQUEST['lon'];
} else {
   $lng = $SITE['longitude'];
}

// TimeZone
if(isset($_REQUEST['locale'])){
   $time_locale = $_REQUEST['locale'];
}
if(function_exists('date_default_timezone_set')){ // includes check for PHP 5+
	if(date_default_timezone_set($time_locale)){
		$ok5 = true;
	}else{
		$ok5 = false;
	}
}else{
		$ok5 = false;
}

// date / timestamp
if(isset($_REQUEST['event'])){ 
   $then = $_REQUEST['event'];
   if(is_numeric($then)){ // should be unix timetamp
     $when = $then;
   } else { // expecting ISO format YYYY-MM-DD*hh:mm    * is important
      $temp = str_replace('*', ' ', $then);
      $when = strtotime($temp);
   }
}
if(!$when){ // if no timestamp posted - OR - ISO fails to be parsed $when would be false
   $when = time();
}

$now = time(); // for timeToDie comparison check
$out = "1"; // default 'light'

// forecastnumber
if(!isset($_REQUEST['fno'])){ // forecast number has NOT been passed, try realtime.txt
   
   $dataraw = @file($realtime);

   if($dataraw){ // something back
     $dataraw = preg_replace("/[\r\n]+[\s\t]*[\r\n]+/","",$dataraw);
     $data=explode(" ", $dataraw[0]);
// clean up and define

      $dd = substr($data[0], 0, 2);
      $mm = substr($data[0], 3, 2);
      $yyyy = "20" .substr($data[0], -2);
      $hh = substr($data[1], 0, 2);
      $min = substr($data[1], 3, 2);
      $when = strtotime($yyyy.'-'.$mm.'-'.$dd.' '.$data[1]);
      $fno = $data[48];
  }
} else {
   $fno = $_REQUEST['fno'];
}

if($when + $timeToDie *60 *60 < $now && $ok5) $fno = 0; // age check (won't apply if using 'now' time)

// *** Main work area ************
if($fno && $ok5){
   $sun_info = date_sun_info($when, $lat, $lng);

// civil twilight

   $eventRise = $sun_info['civil_twilight_begin'];
   if($eventRise == 1) $eventRise = null; // imitate date_sunrise 'format'
   if($eventRise !=null && $eventRise < $when ) $eventRise = null; // event has passed current time
   $eventSet = $sun_info['civil_twilight_end'];
   if($eventSet == 1) $eventSet = null; // imitate date_sunset 'format'
   if($eventSet !=null && $eventSet < $when) $eventSet = null; // event has passed current time

   if($eventRise == null && $eventSet == null){ // need to find 'next' event
      $checkDate = $when;
      for($x = 1; $x < 366 ; $x++){ // step forwards to find next event transition
         $checkDate = $when + ($x * 24 * 60 * 60); // day(s) into the future
         $check_info = date_sun_info($checkDate, $lat, $lng);
         $eventRise = $check_info['civil_twilight_begin'];
         if($eventRise == 1) $eventRise = null; // imitate date_sunrise 'format'
         $eventSet = $check_info['civil_twilight_end'];
         if($eventSet == 1) $eventSet = null; // imitate date_sunset 'format'
      
         if($eventRise != null || $eventSet != null) break; // we have found next event transition
      }
   }

// what was it ?
   if($eventRise != null && $eventSet != null){ // BOTH events are taking place, which is 'next' ?
      ($eventRise < $eventSet ? $eventSet = null : $eventRise = null);
   }
   if($eventRise){ // next event is 'light'
      $out = ($when + $lead *60 *60 > $eventRise ? "1" : "0"); // check against your 'lead' time
   }
   if($eventSet){ // next event is 'dark'
      $out = ($when + $lead *60 *60 > $eventSet ? "0" : "1"); // check against your 'lead' time
   }
  
// END civil twilight
} 
if(!$fno) $fno = "0"; // belt 'n' braces check

// force variables for testing
// $frz = 0; // 1 <= 32 degrees, 0 > 32 degrees
// $out = 1; // 1 == daylight, 0 == nighttime
// $fno = 19; // rain/snow
// ++$frz;
// --$frz;
// end of force variables for testing

header('Content-Type: image/'.$imageType);
header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past
// readfile($icons.$imagePrefix.$out.'_'.$fno.'.'.$imageType); // original
readfile($icons.$imagePrefix.$frz.'_'.$out.'_'.$fno.'.'.$imageType); // adding for "is/not" freezing

?>
