var chart;

var temperature = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Temperature'
		},

		subtitle : {
			text : 'Daily Temperatures (°F)'
		},

		xAxis : {
			type : 'datetime',
			maxPadding : 0,
			minPadding : 0,
			dateTimeLabelFormats : {
				day : '%e %b',
				week : '%e %b %y',
				month : '%b %y',
				year : '%Y'
			}
		},

		yAxis : [
            { // left y axis
				title : {
					text : null
				},
				labels : {
					align : 'right',
					x : -5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 0);
					}
				},
				plotBands : [
                    {
						// visualize sub-zero
						from : -200,
						to : 32, /* 32 degrees for F, 0 degrees for C */
						color : 'rgba(68, 170, 213, .1)'
					}, {
						// min record
						from : -200,
						to : -10,
						color : 'rgba(68, 170, 213, .2)'
					}, {
						// max record
						from : 30,
						to : 200,
						color : 'rgba(243, 170, 68, .2)'
					}
				],
				plotLines : [
                    {
						// visualize zero
						value : 32, /* 32 degrees for F, 0 degrees for C */
						color : 'rgb(0, 0, 180)',
						width : 1,
						zIndex : 2
					}
				]
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 0);
					}
				}
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			shared : true,
			crosshairs : true,
			valueSuffix : '°F'
		},

		plotOptions : {
			series : {
				cursor : 'pointer',
				marker : {}
			},
            line : {
                lineWidth : 1
            },
            spline : {
                lineWidth : 2
            }
		},

		series : [
            {
				name : 'Min temp',
				pointInterval : 24 * 3600 * 1000,
				marker : {
					enabled : false,
					states : {
						hover : {
							enabled : true,
							radius : 5
						}
					}
				}
			}, {
				name : 'Avg temp',
				pointInterval : 24 * 3600 * 1000,
				marker : {
					enabled : false,
					states : {
						hover : {
							enabled : true,
							radius : 5
						}
					}
				}
			}, {
				name : 'Max temp',
				pointInterval : 24 * 3600 * 1000,
				marker : {
					enabled : false,
					states : {
						hover : {
							enabled : true,
							radius : 5
						}
					}
				}
			}
		]
	};

	var update = function (months) {
		try {
			chart.showLoading();
		} catch (e) {}
		$.ajax({
			url : 'historicTemperature.php?months=' + months,
			datatype : "json",
			success : function (resp) {

				options.chart.type = months > 6 ? 'line' : 'spline';

				// data returned = [startDate, minRec, maxRec, minArr[], maxArr[], avgArr[]]
				// min
				options.series[0].pointStart = resp[0];
				options.series[0].data = resp[3];
				// avg
				options.series[1].pointStart = resp[0];
				options.series[1].data = resp[5];
				// max
				options.series[2].pointStart = resp[0];
				options.series[2].data = resp[4];

				// plot min/max records
				options.yAxis[0].plotBands[1].to = resp[1];
				options.yAxis[0].plotBands[2].from = resp[2];

				chart = new Highcharts.Chart(options);
			},
		});
	};

	return {
		update : update
	};
}());


var pressure = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container',
			type : 'areasplinerange'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Atmospheric Pressure'
		},

		subtitle : {
			text : 'Sea Level Pressure (in)'
		},

		xAxis : {
			type : 'datetime',
			labels : {
				align : 'left'
			},
			maxPadding : 0,
			minPadding : 0,
			dateTimeLabelFormats : {
				day : '%e %b',
				week : '%e %b %y',
				month : '%b %y',
				year : '%Y'
			}
		},

		yAxis : [
            { // left y axis
				title : {
					text : null
				},
				labels : {
					align : 'right',
					x : -5,
					formatter : function () {
						return parseInt(this.value, 10);
					}
				},
				plotBands : [// visualize record ranges
					{
						from : 1050,
						to : 2000,
						color : 'rgba(243, 170, 68, .2)'
					}, {
						from : 0,
						to : 950,
						color : 'rgba(243, 170, 68, .2)'
					}
				]
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
					formatter : function () {
						return parseInt(this.value, 10);
					}
				}
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			shared : true,
			crosshairs : true,
			valueSuffix : ' in'
		},

		plotOptions : {
			series : {
				cursor : 'pointer',
                lineWidth : 1
			}
		},

		series : [
            {
				name : 'Pressure range',
				pointInterval : 24 * 3600 * 1000
			}
		]
	};

	var update = function (months) {
		chart.showLoading();
		$.ajax({
			url : 'historicPressure.php?months=' + months,
			datatype : "json",
			success : function (resp) {

				options.chart.type = months > 6 ? 'arearange' : 'areasplinerange';

				options.series[0].data = resp[2];

				options.yAxis[0].plotBands[0].from = resp[1];
				options.yAxis[0].plotBands[1].to = resp[0];

				chart = new Highcharts.Chart(options);
			},
		});
	};

	return {
		update : update
	};
}());


var wind = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Wind Speeds'
		},

		subtitle : {
			text : 'Daily Wind Speeds (mph)'
		},

		xAxis : {
			type : 'datetime',
			maxPadding : 0,
			minPadding : 0,
			labels : {
				align : 'left'
			},
			dateTimeLabelFormats : {
				day : '%e %b',
				week : '%e %b %y',
				month : '%b %y',
				year : '%Y'
			}

		},

		yAxis : [
            { // left y axis
				title : {
					text : null
				},
				labels : {
					align : 'right',
					x : -5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 0);
					}
				},
				min : 0
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 0);
					}
				},
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			shared : true,
			crosshairs : true,
			valueSuffix : ' mph'
		},

		plotOptions : {
			series : {
				cursor : 'pointer',
				marker : {}
			},
            line : {
                lineWidth : 1
            },
            spline : {
                lineWidth : 2
            }
		},

		series : [
            {
				name : 'Avg speed',
				pointInterval : 24 * 3600 * 1000,
				marker : {
					enabled : false,
					states : {
						hover : {
							enabled : true,
							radius : 5
						}
					}
				}
			}, {
				name : 'Max gust speed',
				pointInterval : 24 * 3600 * 1000,
				color : 'rgba(255,0,0,0.8)',
				marker : {
					enabled : false,
					states : {
						hover : {
							enabled : true,
							radius : 5
						}
					}
				}
			}
		]
	};

	var update = function (months) {
		chart.showLoading();
		$.ajax({
			url : 'historicWind.php?months=' + months,
			datatype : "json",
			success : function (resp) {

				options.chart.type = months > 6 ? 'line' : 'spline';

				// avg
				options.series[0].pointStart = resp[0];
				options.series[0].data = resp[1];
				// gust
				options.series[1].pointStart = resp[0];
				options.series[1].data = resp[2];

				chart = new Highcharts.Chart(options);
			},
		});
	};

	return {
		update : update
	};
}());


var rainMonthly = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container',
			type : 'column'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Rain by Month'
		},

		subtitle : {
			text : 'Monthly Rainfall (in)'
		},

		xAxis : {
			gridLineWidth : 0,
			minorGridLineWidth : 0
		},

		yAxis : [
            { // left y axis
				//min: 0,
				title : {
					text : null
				},
				gridLineWidth : 0,
				labels : {
					align : 'right',
					x : -5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 2);
					}
				}
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 2);
					}
				}
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			formatter : function () {
				return '' + this.x + ' ' + this.series.name + ': ' + Highcharts.numberFormat(this.y, 1) + ' in';
			}
		},

		plotOptions : {
			column : {
				groupPadding : 0.1,
				pointPadding : 0.1,
				borderWidth : 0
			}
		},

		series : [
            {
				name : 'Monthly rainfall'
			}
		]
	};

	var update = function (months) {
		chart.showLoading();
		$.ajax({
			url : 'historicRainMonthly.php?months=' + months,
			datatype : "json",
			success : function (resp) {

				options.xAxis.categories = resp[0];

				options.series[0].data = resp[1];

				chart = new Highcharts.Chart(options);
			}
		}); // end ajax()
	};

	return {
		update : update
	};
}());


var rainByYear = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Rain by Year'
		},

		subtitle : {
			text : 'Monthly Rainfall (in)'
		},

		xAxis : {
			categories : [
				'Jan',
				'Feb',
				'Mar',
				'Apr',
				'May',
				'Jun',
				'Jul',
				'Aug',
				'Sep',
				'Oct',
				'Nov',
				'Dec'
			]
		},

		yAxis : [
            { // left y axis
				//min: 0,
				title : {
					text : null
				},
				labels : {
					align : 'right',
					x : -5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 2);
					}
				}
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
					formatter : function () {
						return Highcharts.numberFormat(this.value, 2);
					}
				}
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			formatter : function () {
				return '' + this.x + ' ' + this.series.name + ': ' + Highcharts.numberFormat(this.y, 1) + ' in';
			}
		},

		plotOptions : {
			column : {
				groupPadding : 0.1,
				pointPadding : 0.1,
				borderWidth : 0
			}
		},

		series : [{}]
	};

	var update = function () {
		chart.showLoading();
		$.ajax({
			url : 'historicRainYearly.php',
			datatype : "json",
			success : function (resp) {
                var i = 0;

				for (; i < resp[0].length; i++) {
					options.series[i] = {
						type : 'column',
						name : resp[0][i],
						data : resp[1][i],
						color : 'rgb(' + (150 - i * 30) + ',' + (150 - i * 30) + ',' + (255 - i * 30) + ')'
					};
				};
                options.series[0].pointStart = 4;
				options.series[i] = {
					name : 'Regional Avg.',
					marker : {
						enabled : false
					},
					step : 'center',
					data : [0.43, 0.48, 0.75, 0.60, 0.59, 0.68, 1.36, 1.82, 1.07, 1.05, 0.68, 0.57],
					color : '#F06060'
				};

				chart = new Highcharts.Chart(options);
			}
		}); // end ajax()
	};

	return {
		update : update
	};
}());


var rainDaily = (function () {
	// define the options
	var options = {

		chart : {
			renderTo : 'container',
			type : 'column'
		},

		credits : {
			enabled : false
		},

		title : {
			text : 'Historic Rain by Day'
		},

		subtitle : {
			text : 'Daily Rainfall (in)'
		},

		xAxis : {
			type : 'datetime',
			dateTimeLabelFormats : {
				day : '%e %b',
				week : '%e %b %y',
				month : '%b %y',
				year : '%Y'
			},
			gridLineWidth : 0,
			minorGridLineWidth : 0
		},

		yAxis : [
            { // left y axis
				//min: 0,
				title : {
					text : null
				},
				labels : {
					align : 'right',
					x : -5,
				formatter : function () {
						return Highcharts.numberFormat(this.value, 2);
					}
				}
			}, { // right y axis
				linkedTo : 0,
				gridLineWidth : 0,
				opposite : true,
				title : {
					text : null
				},
				labels : {
					align : 'left',
					x : 5,
				formatter : function () {
					return Highcharts.numberFormat(this.value, 2);
					}
				},
			}
		],

		legend : {
			align : 'left',
			verticalAlign : 'top',
			y : 20,
			floating : true,
			borderWidth : 0
		},

		tooltip : {
			valueSuffix : " in"
		},

		plotOptions : {
			column : {
				pointPadding : 0.05,
				borderWidth : 0,
				cropThreshold : 500,
				minPointLength : 2,
				groupPadding : 0.1
			}
		},

		series : [
            {
				name : 'Daily rainfall',
				pointInterval : 24 * 3600 * 1000
			}
		]
	};

	var update = function (months) {
		chart.showLoading();
		$.ajax({
			url : 'historicRainDaily.php?months=' + months,
			datatype : "json",
			success : function (resp) {

				options.plotOptions.column.shadow = (months <= 3);

				options.series[0].pointStart = resp[0];
				options.series[0].data = resp[1];

				chart = new Highcharts.Chart(options);
			}
		}); // end ajax()
	};

	return {
		update : update
	};
}());